function log(msg) {
  console.log("[Bahn Insight] " + msg);
}

function getMediaURL(path) {
  path = "media/" + path;
  return chrome.runtime.getURL(path) || browser.runtime.getURL(path);
}

/**
  * Return train name in format "PRODUCT TRAIN_NUMER"
  * i.e. "ICE 112", "RE 12734"
  * Sometimes train name is in format "PRODUCT LINE_NUMER (TRAIN_NUMER)"
  * i.e. "STB 12 (62371)"
  * Sometimes 'trains' are not trains or we can't find an unique id for them
  * i.e. busses, ferrys, trams
  * they will also be cleaned up and returned as undefined, because we can't link to them correctly
  */
function bahnParseTrainName(dirty_train_name) {
  var name_list = dirty_train_name.split(" ");

  // Train name in format "STB 12 (23561)"
  if(name_list.length == 3 && name_list[2].charAt(0) == '(' && name_list[2].charAt(name_list[2].length-1) == ')') {
    return name_list[0] + " " + name_list[2].substring(1, name_list[2].length-1);
  }

  // Exclude linking to specific products
  if(["bus", "fäh", "str"].indexOf(name_list[0].toLowerCase()) !== -1) {
    return undefined;
  }

  return dirty_train_name;
}

var observer = new MutationObserver((mutations, observer) => {
    mutations.forEach((mutation) => {
      if (mutation.type === 'childList') {
        var target = mutation.target;
        if (target.tagName === 'TD') {
          var timetable = target.querySelector("td div.detailContainer table.result tbody");
          var products = timetable.querySelectorAll("tr.first td.products");
          products.forEach((product) => {
            var train_name = bahnParseTrainName(product.querySelector("span a").innerText);
            if(typeof train_name !== 'undefined') {
              product.innerHTML = product.innerHTML + ' <a href="https://marudor.de/details/' + train_name + '" target="_blank"><img src="' + getMediaURL("marudor.svg") + '" style="height: 2em; vertical-align:middle;"></a>';
            }
          });
          var stations = timetable.querySelectorAll("tr td.station");
          stations.forEach((station) => {
            var station_name = station.innerText;
            station.innerHTML = station.innerHTML + ' <a href="https://marudor.de/' + station_name + '" target="_blank"><img src="' + getMediaURL("marudor.svg") + '" style="height: 2em; vertical-align:middle;"></a>';
          });

        }
      }
    });
});


var target = document.getElementById('resultsOverview');

if(typeof target !== 'undefined') {
  observer.observe(target, {
    subtree: true,
    childList: true
  });
}
